.. list-table:: rcParams
   :widths: 25 25 50
   :header-rows: 1

    * - Parameter
      - Default Value
    * - ion.missing_intensity_thresh
    - 1
    * - ion.impute_type
    - gaussian
    * - ion.aon_impute_loc
    - 10000.0
    * - ion.aon_impute_scale
    - 1000.0
    * - trp_protein.intensity_value
    - MaxLFQ Intensity
    * - trp_protein.fc_sig_tresh
    - 1.0
    * - trp_protein.pval_sig_tresh
    - 0.01
    * - protein.fc_sig_thresh
    - 1.0
    * - protein.pval_sig_thresh
    - 0.01
    * - protein.adj_pval_sig_thresh
    - 0.05
    * - protein.high_fc_sig_thresh
    - 6.0
    * - protein.high_pval_sig_thresh
    - 0.016
